/* help.h
 * header files for help.c
 *
 * for Denemo, a gtk+ frontend to GNU Lilypond
 * (c) 2000-2005 Matthew Hiller
 */

void about (GtkAction * action, DenemoScriptParam* param);
void browse_manual (GtkAction * action, DenemoScriptParam* param);
